###-------------------------------###
### BRM Session 4 - Visualization ###
###-------------------------------###
# Dennis Abel and Lukas Birkenmaier

# Intro and setup -------------------------------------------------------------------

# Now we turn towards visualization. The ggplot-package from the tidyverse is very comprehensive 
# and enables us to produce custom-made visualizations. We will introduce ggplot and the
# "grammar of graphics" in R today. However, we will come back to advanced visualizations for univariate 
# and bivariate data in the next sessions on descriptive statistics.

# Load required packages
library(tidyverse)

# Working directory
setwd("[insert directory here]")

# In the last session, we cleaned our dataframe. Instead of loading the raw data from the csv-file,
# we can load our cleaned RDS-object.

# Use read_rds-function to load rds data
oddjob <- read_rds("oddjob.rds")


# Understanding the logic of geoms ----------------------------------------

# Plot our first ggplot-graph
ggplot(data=oddjob)+
  geom_point(mapping=aes(x=age,y=nflights))

# Plot one scatterplot with ggplot and adjust point color based on third variable
ggplot(data=oddjob)+
  geom_point(mapping=aes(x=age,y=nflights, color=status))+
  ylim(0,100)+
  xlim(20,80)

# Adjust shape of points
ggplot(data=oddjob)+
  geom_point(mapping=aes(x=age,y=nflights, shape=status))+
  ylim(0,100)+
  xlim(20,80)

# Adjust color manually
ggplot(data=oddjob)+
  geom_point(mapping=aes(x=age,y=nflights), color="blue")+
  ylim(0,100)+
  xlim(20,80)

# Facets based on status-variable
ggplot(data=oddjob)+
  geom_point(mapping=aes(x=age,y=nflights))+
  ylim(0,100)+
  xlim(20,80) +
  facet_wrap(~status)


# Data transformation and plots -------------------------------------------

# If you want to plot graphs of transformed variables, you can combine
# ggplot with prior data transformation steps with the pipe

oddjob |> 
  filter(age > 40) |> 
  ggplot()+
  geom_point(mapping=aes(x=age,y=nflights))

# ylim and xlim to adjust axis scales
# With labs you can adjust titles, caption, x- and y-titles as well as the title of the
# color/shape-legend
# Theme adjustable
# Color scheme adjustable with scale_color_brewer, scale_color_manual etc.
# "\n" in text for line breaks

plot <- ggplot(data=oddjob, mapping=aes(x=age,y=nflights, color=status))+
  geom_point()+
  geom_smooth(se=FALSE)+
  coord_cartesian(xlim=c(20,80), ylim=c(0,100))+
  labs(title="Relationship between customer age and number of flights",
       subtitle = "The colors show the customer status",
       caption = "Data from Sarstedt and Mooi (2019)",
       x = "Age of customer (years)",
       y = "Number of flights",
       color = "Customer \nstatus")+
  scale_color_brewer(palette = "Dark2")+
  theme_bw()

# Once you are happy with your plot, you can export it. You can export it as pdf or
# png. Windows users should check that the "cairo"-device is used when plotting pngs,
# otherwise anti-aliasing is turned off.
ggsave(plot, filename = "plot_1.png", dpi = 300, type="cairo",
       width = 7, height = 5, units = "in")

ggsave(plot, filename = "plot_1.pdf", dpi = 300,
       width = 7, height = 5, units = "in")
